# Empty workspace
rm(list = ls(all = TRUE))
ls()


# Create test dataframe
test <- data.frame(Letters = c("f", "e", "g", "d", "h", "b", "i", "a", NA, "j"), 
                       Mix = c("b2", "", "b3", "a2", NA, "b1", "a1", "b2", "c4", "d5"),
                   Numbers = c(2,3,NA,4,6,NA,5,3,10,8),
                   Boolean = c(F, T, T, T, F, F, T, T, F, F),
                               stringsAsFactors = FALSE)

dim(test)
# 10  4

nrow(test)
# 10

ncol(test)
# 4

length(test)
# 4

test
#   Letters  Mix Numbers Boolean
#1        f   b2       2   FALSE
#2        e            3    TRUE
#3        g   b3      NA    TRUE
#4        d   a2       4    TRUE
#5        h <NA>       6   FALSE
#6        b   b1      NA   FALSE
#7        i   a1       5    TRUE
#8        a   b2       3    TRUE
#9     <NA>   c4      10   FALSE
#10       j   d5       8   FALSE


#ind <- order(test[,1], na.last = TRUE, decreasing = FALSE)
#ind

test.Letters <- test[order(test[,1], na.last = TRUE, decreasing = FALSE),]
test.Letters
#   Letters  Mix Numbers Boolean
#8        a   b2       3    TRUE
#6        b   b1      NA   FALSE
#4        d   a2       4    TRUE
#2        e            3    TRUE
#1        f   b2       2   FALSE
#3        g   b3      NA    TRUE
#5        h <NA>       6   FALSE
#7        i   a1       5    TRUE
#10       j   d5       8   FALSE
#9     <NA>   c4      10   FALSE

test.Mix     <- test[order(test[,2], na.last = TRUE, decreasing = FALSE),]
test.Mix
#   Letters  Mix Numbers Boolean
#2        e            3    TRUE
#7        i   a1       5    TRUE
#4        d   a2       4    TRUE
#6        b   b1      NA   FALSE
#1        f   b2       2   FALSE
#8        a   b2       3    TRUE
#3        g   b3      NA    TRUE
#9     <NA>   c4      10   FALSE
#10       j   d5       8   FALSE
#5        h <NA>       6   FALSE

test.Numbers <- test[order(test[,3], na.last = TRUE, decreasing = FALSE),]
test.Numbers
#   Letters  Mix Numbers Boolean
#1        f   b2       2   FALSE
#2        e            3    TRUE
#8        a   b2       3    TRUE
#4        d   a2       4    TRUE
#7        i   a1       5    TRUE
#5        h <NA>       6   FALSE
#10       j   d5       8   FALSE
#9     <NA>   c4      10   FALSE
#3        g   b3      NA    TRUE
#6        b   b1      NA   FALSE

test.Boolean <- test[order(test[,4], na.last = TRUE, decreasing = FALSE),]
test.Boolean
#   Letters  Mix Numbers Boolean
#1        f   b2       2   FALSE
#5        h <NA>       6   FALSE
#6        b   b1      NA   FALSE
#9     <NA>   c4      10   FALSE
#10       j   d5       8   FALSE
#2        e            3    TRUE
#3        g   b3      NA    TRUE
#4        d   a2       4    TRUE
#7        i   a1       5    TRUE
#8        a   b2       3    TRUE

# Two sort steps in one command
# Note that "na.last" and "decreasing" parameters are not the obligatory ones
test.Boolean.Numbers <- test[order(test$Boolean, test$Numbers),] 
test.Boolean.Numbers
#    Letters  Mix Numbers Boolean
# 1        f   b2       2   FALSE
# 5        h <NA>       6   FALSE
# 10       j   d5       8   FALSE
# 9     <NA>   c4      10   FALSE
# 6        b   b1      NA   FALSE
# 2        e            3    TRUE
# 8        a   b2       3    TRUE
# 4        d   a2       4    TRUE
# 7        i   a1       5    TRUE
# 3        g   b3      NA    TRUE

# OR the same by using the function "with"
test.Boolean.Numbers <- test[with(test, order(Boolean, Numbers)),]
test.Boolean.Numbers
#    Letters  Mix Numbers Boolean
# 1        f   b2       2   FALSE
# 5        h <NA>       6   FALSE
# 10       j   d5       8   FALSE
# 9     <NA>   c4      10   FALSE
# 6        b   b1      NA   FALSE
# 2        e            3    TRUE
# 8        a   b2       3    TRUE
# 4        d   a2       4    TRUE
# 7        i   a1       5    TRUE
# 3        g   b3      NA    TRUE

# Simultaneous removal of NAs by using "na.omit" function
test.Boolean.Numbers <- na.omit(test[with(test, order(Boolean, Numbers)),])
test.Boolean.Numbers
#    Letters Mix Numbers Boolean
# 1        f  b2       2   FALSE
# 10       j  d5       8   FALSE
# 2        e           3    TRUE
# 8        a  b2       3    TRUE
# 4        d  a2       4    TRUE
# 7        i  a1       5    TRUE

# Data subsetting (test$Numbers should be more than 3)
test.Boolean.Numbers <- test.Boolean.Numbers[test.Boolean.Numbers$Numbers > 3,]
test.Boolean.Numbers
#    Letters Mix Numbers Boolean
# 10       j  d5       8   FALSE
# 4        d  a2       4    TRUE
# 7        i  a1       5    TRUE
